pub struct MatchmakingCache {
pub character_id: Uuid,
pub opponent_ids: Vec<Uuid>,
pub need_refresh: bool,
pub is_free_refresh_available: bool,
}Fields
character_id: Uuidopponent_ids: Vec<Uuid>need_refresh: boolis_free_refresh_available: boolTrait Implementations
Sourceimpl Clone for MatchmakingCache
impl Clone for MatchmakingCache
Sourcefn clone(&self) -> MatchmakingCache
fn clone(&self) -> MatchmakingCache
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MatchmakingCache
impl Debug for MatchmakingCache
Sourceimpl<'de> Deserialize<'de> for MatchmakingCache
impl<'de> Deserialize<'de> for MatchmakingCache
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MatchmakingCache
impl JsonSchema for MatchmakingCache
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatchmakingCache
impl PartialEq for MatchmakingCache
Sourceimpl Serialize for MatchmakingCache
impl Serialize for MatchmakingCache
Sourceimpl Tsify for MatchmakingCache
impl Tsify for MatchmakingCache
const DECL: &'static str = "export interface MatchmakingCache {\n character_id: Uuid;\n opponent_ids: Uuid[];\n need_refresh: boolean;\n is_free_refresh_available: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl StructuralPartialEq for MatchmakingCache